@@ -1,4 +1,4 @@
-# Copyright 2018-2025 Jérôme Dumonteil
+# Copyright 2018-2026 Jérôme Dumonteil
 # Copyright (c) 2009-2010 Ars Aperta, Itaapy, Pierlis, Talend.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -22,6 +22,8 @@
 #          Romain Gauthier <romain@itaapy.com>
 
 __all__ = [  # noqa: RUF022
+    "AnchorMix",
+    "AngleMix",
     "AnimPar",
     "AnimSeq",
     "AnimTransFilter",
@@ -29,7 +31,6 @@ __all__ = [  # noqa: RUF022
     "AnnotationEnd",
     "AnnotationMixin",
     "BackgroundImage",
-    "FormButtonTypeMixin",
     "Body",
     "Bookmark",
     "BookmarkEnd",
@@ -38,7 +39,13 @@ __all__ = [  # noqa: RUF022
     "Cell",
     "ChangeInfo",
     "Chart",
+    "CircleShape",
     "Column",
+    "ConfigItem",
+    "ConfigItemMapEntry",
+    "ConfigItemMapIndexed",
+    "ConfigItemMapNamed",
+    "ConfigItemSet",
     "ConnectorShape",
     "Container",
     "Content",
@@ -46,10 +53,16 @@ __all__ = [  # noqa: RUF022
     "DcCreatorMixin",
     "DcDateMixin",
     "Document",
+    "DrawCaption",
+    "DrawControl",
     "DrawFillImage",
     "DrawGroup",
     "DrawImage",
+    "DrawMarker",
+    "DrawMeasure",
     "DrawPage",
+    "DrawPageThumbnail",
+    "DrawPath",
     "DrawTextBox",
     "Drawing",
     "EText",
@@ -106,8 +119,11 @@ __all__ = [  # noqa: RUF022
     "LineBreak",
     "LineShape",
     "Link",
+    "LinkMixin",
     "List",
+    "ListHeader",
     "ListItem",
+    "ListMixin",
     "Manifest",
     "Meta",
     "MetaAutoReload",
@@ -126,11 +142,16 @@ __all__ = [  # noqa: RUF022
     "OfficeForms",
     "OfficeFormsMixin",
     "OfficeMasterStyles",
+    "OfficeSettings",
     "OfficeTargetFrameMixin",
     "PREV_SIBLING",
     "PageBreak",
+    "ParaFormattedTextMixin",
     "ParaMixin",
     "Paragraph",
+    "PolygonShape",
+    "PolylineShape",
+    "PosMix",
     "Presentation",
     "PresentationNotes",
     "RectangleShape",
@@ -139,11 +160,14 @@ __all__ = [  # noqa: RUF022
     "ReferenceMarkEnd",
     "ReferenceMarkStart",
     "ReferenceMixin",
+    "RegularPolygonShape",
     "Row",
     "RowGroup",
     "RubyBase",
     "Section",
     "SectionMixin",
+    "Settings",
+    "SizeMix",
     "Spacer",
     "Span",
     "Spreadsheet",
@@ -157,6 +181,9 @@ __all__ = [  # noqa: RUF022
     "StyleMasterPage",
     "StylePageLayout",
     "Styles",
+    "SvgDescription",
+    "SvgMixin",
+    "SvgTitle",
     "TOC",
     "Tab",
     "TabStopStyle",
@@ -172,10 +199,14 @@ __all__ = [  # noqa: RUF022
     "TextInsertion",
     "TextMeta",
     "TocEntryTemplate",
+    "TocMixin",
     "TrackedChanges",
     "TrackedChangesMixin",
     "UserDefined",
+    "UserDefinedMixin",
     "UserFieldDecl",
+    "UserFieldDeclContMixin",
+    "UserFieldDeclMixin",
     "UserFieldDecls",
     "UserFieldGet",
     "UserFieldInput",
@@ -184,6 +215,7 @@ __all__ = [  # noqa: RUF022
     "VarCreationTime",
     "VarDate",
     "VarDecl",
+    "VarDeclMixin",
     "VarDecls",
     "VarDescription",
     "VarFileName",
@@ -197,6 +229,7 @@ __all__ = [  # noqa: RUF022
     "VarTime",
     "VarTitle",
     "XmlPart",
+    "ZMix",
     "__version__",
     "create_table_cell_style",
     "default_boolean_style",
@@ -213,8 +246,6 @@ __all__ = [  # noqa: RUF022
     "remove_tree",
     "rgb2hex",
 ]
-
-
 from .annotation import Annotation, AnnotationEnd, AnnotationMixin
 from .body import (
     Body,
@@ -223,6 +254,7 @@ from .body import (
     Drawing,
     Image,
     Metadata,
+    OfficeSettings,
     Presentation,
     Spreadsheet,
     Text,
@@ -230,6 +262,13 @@ from .body import (
 from .bookmark import Bookmark, BookmarkEnd, BookmarkMixin, BookmarkStart
 from .cell import Cell
 from .column import Column
+from .config_elements import (
+    ConfigItem,
+    ConfigItemMapEntry,
+    ConfigItemMapIndexed,
+    ConfigItemMapNamed,
+    ConfigItemSet,
+)
 from .container import Container
 from .content import Content
 from .document import Document
@@ -280,13 +319,21 @@ from .form_properties import (
     FormProperties,
     FormProperty,
 )
-from .frame import DrawTextBox, Frame, default_frame_position_style
+from .frame import (
+    AnchorMix,
+    DrawTextBox,
+    Frame,
+    PosMix,
+    SizeMix,
+    ZMix,
+    default_frame_position_style,
+)
 from .header import Header
 from .header_rows import HeaderRows
-from .image import DrawFillImage, DrawImage
+from .image import DrawFillImage, DrawImage, DrawMarker
 from .line_break import LineBreak
 from .link import Link
-from .list import List, ListItem
+from .list import List, ListHeader, ListItem
 from .manifest import Manifest
 from .master_page import (
     StyleFooter,
@@ -305,8 +352,12 @@ from .meta_template import MetaTemplate
 from .meta_user_defined import MetaUserDefined
 from .mixin_dc_creator import DcCreatorMixin
 from .mixin_dc_date import DcDateMixin
+from .mixin_link import LinkMixin
+from .mixin_list import ListMixin
 from .mixin_named_range import NRMixin, TableNamedExpressions
 from .mixin_paragraph import ParaMixin
+from .mixin_paragraph_formatted import ParaFormattedTextMixin
+from .mixin_toc import TocMixin
 from .named_range import NamedRange
 from .note import Note, NoteBody, NoteMixin
 from .office_forms import OfficeForms, OfficeFormsMixin
@@ -324,7 +375,24 @@ from .row import Row
 from .row_group import RowGroup
 from .ruby_base import RubyBase
 from .section import Section, SectionMixin
-from .shapes import ConnectorShape, DrawGroup, EllipseShape, LineShape, RectangleShape
+from .settings import Settings
+from .shapes import (
+    AngleMix,
+    CircleShape,
+    ConnectorShape,
+    DrawCaption,
+    DrawControl,
+    DrawGroup,
+    DrawMeasure,
+    DrawPageThumbnail,
+    DrawPath,
+    EllipseShape,
+    LineShape,
+    PolygonShape,
+    PolylineShape,
+    RectangleShape,
+    RegularPolygonShape,
+)
 from .smil import AnimPar, AnimSeq, AnimTransFilter
 from .spacer import Spacer
 from .style import (
@@ -343,11 +411,14 @@ from .style_defaults import (
     default_time_style,
 )
 from .styles import Styles
+from .svg import SvgDescription, SvgMixin, SvgTitle
 from .tab import Tab
 from .table import Table
-from .text_index import IndexBody, IndexTitle, IndexTitleTemplate
 from .toc import (
     TOC,
+    IndexBody,
+    IndexTitle,
+    IndexTitleTemplate,
     TabStopStyle,
     TocEntryTemplate,
     default_toc_level_style,
@@ -364,12 +435,12 @@ from .tracked_changes import (
     TrackedChanges,
     TrackedChangesMixin,
 )
-from .user_field import (
-    UserDefined,
+from .user_field import UserDefined, UserDefinedMixin, UserFieldGet, UserFieldInput
+from .user_field_declaration import (
     UserFieldDecl,
+    UserFieldDeclContMixin,
+    UserFieldDeclMixin,
     UserFieldDecls,
-    UserFieldGet,
-    UserFieldInput,
 )
 from .utils import hex2rgb, hexa_color, remove_tree, rgb2hex
 from .variable import (
@@ -389,9 +460,6 @@ from .variable import (
     VarTime,
     VarTitle,
 )
-from .variable_declaration import (
-    VarDecl,
-    VarDecls,
-)
+from .variable_declaration import VarDecl, VarDeclMixin, VarDecls
 from .version import __version__
 from .xmlpart import XmlPart
