@@ -1,4 +1,4 @@
-# Copyright 2018-2025 Jérôme Dumonteil
+# Copyright 2018-2026 Jérôme Dumonteil
 # Copyright (c) 2009-2010 Ars Aperta, Itaapy, Pierlis, Talend.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -32,6 +32,7 @@ from .elements_between import elements_between
 from .mixin_dc_creator import DcCreatorMixin
 from .mixin_dc_date import DcDateMixin
 from .mixin_link import LinkMixin
+from .mixin_list import ListMixin
 from .mixin_md import MDTail
 
 if TYPE_CHECKING:
@@ -41,10 +42,19 @@ if TYPE_CHECKING:
 class AnnotationMixin(Element):
     """Mixin class for classes containing Annotations.
 
-    Used by the following classes: "table:covered-table-cell",
-    "table:table-cell", "text:a", "text:h", "text:meta", "text:meta-field",
-    "text:p", "text:ruby-base", "text:span". And with "office:text" and
-    "office:spreadsheet" for compatibility with previous versions.
+    Used by the following classes:
+        - "table:covered-table-cell"
+        - "table:table-cell"
+        - "text:a"
+        - "text:h"
+        - "text:meta"
+        - "text:meta-field"
+        - "text:p"
+        - "text:ruby-base"
+        - "text:span"
+
+    and "office:text", "office:spreadsheet" for compatibility with previous
+    versions.
     """
 
     def get_annotations(
@@ -57,10 +67,10 @@ class AnnotationMixin(Element):
         """Return all the annotations that match the criteria.
 
         Args:
-            creator (str, optional): The creator of the annotation.
-            start_date (datetime, optional): The start date for filtering.
-            end_date (datetime, optional): The end date for filtering.
-            content (str, optional): A regex to match in the content.
+            creator: The creator of the annotation.
+            start_date: The start date for filtering.
+            end_date: The end date for filtering.
+            content: A regex to match in the content.
 
         Returns:
             list[Annotation]: A list of matching Annotation elements.
@@ -95,12 +105,12 @@ class AnnotationMixin(Element):
         """Return the annotation that matches the criteria.
 
         Args:
-            position (int, optional): The position of the annotation to return.
-            creator (str, optional): The creator of the annotation.
-            start_date (datetime, optional): The start date for filtering.
-            end_date (datetime, optional): The end date for filtering.
-            content (str, optional): A regex to match in the content.
-            name (str, optional): The name of the annotation.
+            position: The position of the annotation to return.
+            creator: The creator of the annotation.
+            start_date: The start date for filtering.
+            end_date: The end date for filtering.
+            content: A regex to match in the content.
+            name: The name of the annotation.
 
         Returns:
             Annotation or None: The matching Annotation element, or None if not found.
@@ -149,11 +159,12 @@ class AnnotationMixin(Element):
         """Return the annotation end that matches the criteria.
 
         Args:
-            position (int, optional): The position of the annotation end to return.
-            name (str, optional): The name of the annotation end.
+            position: The position of the annotation end to return.
+            name: The name of the annotation end.
 
         Returns:
-            AnnotationEnd or None: The matching AnnotationEnd element, or None if not found.
+            AnnotationEnd or None: The matching AnnotationEnd element, or
+                None if not found.
         """
         return cast(
             Union[None, AnnotationEnd],
@@ -167,7 +178,7 @@ def get_unique_office_name(element: Element | None = None) -> str:
     """Provide an autogenerated unique "office:name" for the document.
 
     Args:
-        element (Element, optional): The element to which the annotation is related.
+        element: The element to which the annotation is related.
 
     Returns:
         str: A unique name.
@@ -193,7 +204,7 @@ def get_unique_office_name(element: Element | None = None) -> str:
     return name
 
 
-class Annotation(MDTail, LinkMixin, Element, DcCreatorMixin, DcDateMixin):
+class Annotation(MDTail, ListMixin, LinkMixin, Element, DcCreatorMixin, DcDateMixin):
     """An annotation (private note), "office:annotation".
 
     This element contains the content of a comment or annotation, along with
@@ -232,16 +243,15 @@ class Annotation(MDTail, LinkMixin, Element, DcCreatorMixin, DcDateMixin):
         autogenerated to be unique within the document.
 
         Args:
-            text_or_element (Element or str, optional): The content of the
-                annotation, which can be a string or another ODF element.
-            creator (str, optional): The name of the person who created the
-                annotation.
-            date (datetime, optional): The date and time when the annotation
-                was created. Defaults to the current time if not provided.
-            name (str, optional): A unique name for the annotation. If not
-                provided, a unique name is generated.
-            parent (Element, optional): The parent element to which this
-                annotation will be associated for name generation.
+            text_or_element: The content of the annotation, which can be a
+                string or another ODF element.
+            creator: The name of the person who created the annotation.
+            date: The date and time when the annotation was created. Defaults
+                to the current time if not provided.
+            name: A unique name for the annotation. If not provided, a unique
+                name is generated.
+            parent: The parent element to which this annotation will be
+                associated for name generation.
         """
         # fixme : use offset
         # TODO allow paragraph and text styles
@@ -322,12 +332,12 @@ class Annotation(MDTail, LinkMixin, Element, DcCreatorMixin, DcDateMixin):
         empty string if 'as_text' is True.
 
         Args:
-            as_text (bool): If True, returns the text content as a string.
-                            Defaults to False.
-            no_header (bool): If True, converts 'text:h' elements to 'text:p'.
-                              Defaults to True.
-            clean (bool): If True, suppresses unwanted tags such as deletion
-                          marks. Defaults to True.
+            as_text: If True, returns the text content as a string. Defaults
+                to False.
+            no_header: If True, converts 'text:h' elements to 'text:p'.
+                Defaults to True.
+            clean: If True, suppresses unwanted tags such as deletion marks.
+                Defaults to True.
 
         Returns:
             Element | list | str | None: The content of the annotation, which
@@ -352,9 +362,9 @@ class Annotation(MDTail, LinkMixin, Element, DcCreatorMixin, DcDateMixin):
         (if it exists) are deleted.
 
         Args:
-            child (Element, optional): The child element to delete. If None,
+            child: The child element to delete. If None,
                 the annotation itself is deleted. Defaults to None.
-            keep_tail (bool): This argument is not used in this context but is
+            keep_tail: This argument is not used in this context but is
                 kept for compatibility. Defaults to True.
         """
         if child is not None:  # act like normal delete
@@ -414,10 +424,10 @@ class AnnotationEnd(MDTail, Element):
         annotation object directly or by providing a matching name.
 
         Args:
-            annotation (Annotation, optional): The "office:annotation" element
+            annotation: The "office:annotation" element
                 that this "annotation-end" is closing. If provided, the 'name'
                 attribute will be taken from this annotation.
-            name (str, optional): The name of the annotation to close. This is
+            name: The name of the annotation to close. This is
                 required if 'annotation' is not provided.
         """
         # fixme : use offset
