@@ -1,4 +1,4 @@
-# Copyright 2018-2025 Jérôme Dumonteil
+# Copyright 2018-2026 Jérôme Dumonteil
 # Copyright (c) 2009-2012 Ars Aperta, Itaapy, Pierlis, Talend.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -37,6 +37,8 @@ from .annotation import AnnotationMixin
 from .datatype import Boolean, Date, DateTime, Duration
 from .element import Element, register_element_class_list
 from .element_typed import ElementTyped
+from .mixin_list import ListMixin
+from .mixin_toc import TocMixin
 from .section import SectionMixin
 
 _int = builtins.int
@@ -46,7 +48,7 @@ if TYPE_CHECKING:
     from .style import Style
 
 
-class Cell(SectionMixin, AnnotationMixin, ElementTyped):
+class Cell(ListMixin, TocMixin, SectionMixin, AnnotationMixin, ElementTyped):
     """A cell of a table, "table:table-cell" and "table:covered-table-cell"."""
 
     _tag = "table:table-cell"
@@ -73,20 +75,20 @@ class Cell(SectionMixin, AnnotationMixin, ElementTyped):
         repeated across a given number of columns.
 
         Args:
-            value (any, optional): The Python value to set for the cell. Can be
+            value: The Python value to set for the cell. Can be
                 a boolean, int, float, Decimal, date, datetime, str, or timedelta.
-            text (str, optional): The textual representation of the cell's
+            text: The textual representation of the cell's
                 content. If not provided, it is generated from the value.
-            cell_type (str, optional): The explicit type of the cell. Valid
+            cell_type: The explicit type of the cell. Valid
                 options include 'boolean', 'currency', 'date', 'float',
                 'percentage', 'string', or 'time'. If not provided, it's
                 guessed from the value.
-            currency (str, optional): A three-letter currency code (e.g., "EUR",
+            currency: A three-letter currency code (e.g., "EUR",
                 "USD") if the cell_type is 'currency'.
-            formula (str, optional): The formula for the cell.
-            repeated (int, optional): The number of times this cell should be
+            formula: The formula for the cell.
+            repeated: The number of times this cell should be
                 repeated across columns. Must be greater than 1.
-            style (str, optional): The name of the style to apply to the cell.
+            style: The name of the style to apply to the cell.
         """
         super().__init__(**kwargs)
         self.x: int | None = None
@@ -394,16 +396,16 @@ class Cell(SectionMixin, AnnotationMixin, ElementTyped):
         For monetary values, the name of the currency must be provided.
 
         Args:
-            value (Union[str, bytes, float, int, Decimal, bool, datetime, date, timedelta, None]):
+            value:
                 The Python value to assign to the cell.
-            text (str, optional): The explicit textual representation of the
+            text: The explicit textual representation of the
                 cell's content. If None, it is derived from the `value`.
-            cell_type (str, optional): The explicit type of the cell's value.
+            cell_type: The explicit type of the cell's value.
                 Can be 'boolean', 'float', 'date', 'string', 'time', 'currency',
                 or 'percentage'.
-            currency (str, optional): A string representing the currency, e.g.,
+            currency: A string representing the currency, e.g.,
                 "EUR" or "USD", required if `cell_type` is 'currency'.
-            formula (str, optional): The formula to set for the cell.
+            formula: The formula to set for the cell.
         """
         self.clear()
         text = self.set_value_and_type(
@@ -453,7 +455,7 @@ class Cell(SectionMixin, AnnotationMixin, ElementTyped):
         triggering cache updates.
 
         Args:
-            repeated (int, optional): The number of times the cell should be
+            repeated: The number of times the cell should be
                 repeated. If None or less than 2, the attribute is removed.
         """
         if repeated is None or repeated < 2:
@@ -528,7 +530,7 @@ class Cell(SectionMixin, AnnotationMixin, ElementTyped):
         spanned. By default, cells with a style are not considered empty.
 
         Args:
-            aggressive (bool, optional): If True, a cell with a style but no
+            aggressive: If True, a cell with a style but no
                 content is also considered empty. Defaults to False.
 
         Returns:
@@ -562,7 +564,7 @@ class Cell(SectionMixin, AnnotationMixin, ElementTyped):
         or 'table:number-rows-spanned' attributes.
 
         Args:
-            covered (bool, optional): If True, covered cells (those with the
+            covered: If True, covered cells (those with the
                 "table:covered-table-cell" tag) are also considered spanned.
                 Defaults to True.
 
