@@ -1,4 +1,4 @@
-# Copyright 2018-2025 Jérôme Dumonteil
+# Copyright 2018-2026 Jérôme Dumonteil
 # Copyright (c) 2009-2010 Ars Aperta, Itaapy, Pierlis, Talend.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -25,16 +25,23 @@ from __future__ import annotations
 
 from collections.abc import Iterable
 from decimal import Decimal
-from typing import Any
+from typing import TYPE_CHECKING, Any, Union, cast
+
+from odfdo.mixin_list import ListMixin
 
 from .element import Element, PropDef, register_element_class
 from .image import DrawImage
 from .mixin_md import MDDrawFrame, MDDrawTextBox
+from .mixin_toc import TocMixin
 from .paragraph import Paragraph
 from .section import SectionMixin
 from .style import Style
+from .svg import SvgMixin
 from .unit import Unit
 
+if TYPE_CHECKING:
+    from .element import PropDefBool
+
 # This DPI is computed to have:
 # 640 px (width of your wiki) <==> 17 cm (width of a normal ODT page)
 DPI: Decimal = 640 * Decimal("2.54") / 17
@@ -64,12 +71,15 @@ def default_frame_position_style(
     )
 
 
-class AnchorMix:
+class AnchorMix(Element):
     """Anchor parameter, how the element is attached to its environment.
 
     value can be: 'page', 'frame', 'paragraph', 'char' or 'as-char'
     """
 
+    _tag = "draw:anchormix-odfdo-notodf"
+    _properties: tuple[PropDef | PropDefBool, ...] = ()
+
     ANCHOR_VALUE_CHOICE = {  # noqa: RUF012
         "page",
         "frame",
@@ -80,33 +90,32 @@ class AnchorMix:
 
     @property
     def anchor_type(self) -> str | None:
-        "Anchor_type getter/setter."
-        return self.get_attribute_string("text:anchor-type")  # type: ignore
+        'Get or set the anchor type "text:anchor-type".'
+        return self.get_attribute_string("text:anchor-type")
 
     @anchor_type.setter
     def anchor_type(self, anchor_type: str) -> None:
         if anchor_type not in self.ANCHOR_VALUE_CHOICE:
             raise TypeError(f"anchor_type not valid: '{anchor_type!r}'")
-        self.set_attribute("text:anchor-type", anchor_type)  # type: ignore
+        self.set_attribute("text:anchor-type", anchor_type)
 
     @property
     def anchor_page(self) -> int | None:
-        """Getter/setter for the number of the page when the anchor type is
-        'page'.
+        """Get or set the number of the page when the anchor type is 'page'.
 
         type : int or None
         """
-        anchor_page = self.get_attribute("text:anchor-page-number")  # type: ignore
+        anchor_page = self.get_attribute("text:anchor-page-number")
         if anchor_page is None:
             return None
         return int(anchor_page)
 
     @anchor_page.setter
     def anchor_page(self, anchor_page: int | None) -> None:
-        self.set_attribute("text:anchor-page-number", anchor_page)  # type: ignore
+        self._set_attribute_int("text:anchor-page-number", anchor_page)
 
 
-class PosMix:
+class PosMix(Element):
     """Position relative to anchor point.
 
     Setting the position may require a specific style for actual display on
@@ -116,56 +125,77 @@ class PosMix:
     ('10cm', '15cm').
     """
 
+    _tag = "draw:posmixin-odfdo-notodf"
+    _properties: tuple[PropDef | PropDefBool, ...] = (
+        PropDef("pos_x", "svg:x"),
+        PropDef("pos_y", "svg:y"),
+    )
+
     @property
-    def position(self) -> tuple:
-        "getter/setter"
-        get_attr = self.get_attribute  # type: ignore
+    def position(self) -> tuple[str | None, str | None]:
+        'Get or set the tuple of position ("svg:x", "svg:y").'
+        get_attr = self.get_attribute_string
         return get_attr("svg:x"), get_attr("svg:y")
 
     @position.setter
-    def position(self, position: tuple | list) -> None:
+    def position(self, position: tuple[str, str] | list[str]) -> None:
         self.pos_x = position[0]
         self.pos_y = position[1]
 
 
-class ZMix:
+PosMix._define_attribut_property()
+
+
+class ZMix(Element):
     """Z-index position.
 
     z-index is an integer.
     """
 
+    _tag = "draw:zmix-odfdo-notodf"
+    _properties: tuple[PropDef | PropDefBool, ...] = ()
+
     @property
     def z_index(self) -> int | None:
-        "getter/setter"
-        z_index = self.get_attribute("draw:z-index")  # type: ignore
-        if z_index is None:
-            return None
-        return int(z_index)
+        'Get or set the z index "draw:z-index"'
+        return cast(
+            Union[None, int],
+            self.get_attribute_integer("draw:z-index"),
+        )
 
     @z_index.setter
-    def z_index(self, z_index: int) -> None:
-        self.set_attribute("draw:z-index", z_index)  # type: ignore
+    def z_index(self, z_index: int | None) -> None:
+        self._set_attribute_int("draw:z-index", z_index)
 
 
-class SizeMix:
+class SizeMix(Element):
     """Size of the frame.
 
     Size is a (width, height) tuple with items including the unit, e.g.
     ('10cm', '15cm').
     """
 
+    _tag = "draw:sizemix-odfdo-notodf"
+    _properties: tuple[PropDef | PropDefBool, ...] = (
+        PropDef("width", "svg:width"),
+        PropDef("height", "svg:height"),
+    )
+
     @property
-    def size(self) -> tuple:
-        "getter/setter"
+    def size(self) -> tuple[str | None, str | None]:
+        'Get or set the tuple of size ("svg:width", "svg:height").'
         return (self.width, self.height)
 
     @size.setter
-    def size(self, size: tuple | list) -> None:
+    def size(self, size: tuple[str, str] | list[str]) -> None:
         self.width = size[0]
         self.height = size[1]
 
 
-class Frame(MDDrawFrame, Element, AnchorMix, PosMix, ZMix, SizeMix):
+SizeMix._define_attribut_property()
+
+
+class Frame(MDDrawFrame, SvgMixin, AnchorMix, PosMix, ZMix, SizeMix, Element):
     """ODF Frame, "draw:frame".
 
     Frames are not useful by themselves. Consider calling Frame.image_frame()
@@ -173,14 +203,10 @@ class Frame(MDDrawFrame, Element, AnchorMix, PosMix, ZMix, SizeMix):
     """
 
     _tag = "draw:frame"
-    _properties = (
+    _properties: tuple[PropDef | PropDefBool, ...] = (
         PropDef("name", "draw:name"),
         PropDef("draw_id", "draw:id"),
-        PropDef("width", "svg:width"),
-        PropDef("height", "svg:height"),
         PropDef("style", "draw:style-name"),
-        PropDef("pos_x", "svg:x"),
-        PropDef("pos_y", "svg:y"),
         PropDef("presentation_class", "presentation:class"),
         PropDef("layer", "draw:layer"),
         PropDef("presentation_style", "presentation:style-name"),
@@ -218,30 +244,21 @@ class Frame(MDDrawFrame, Element, AnchorMix, PosMix, ZMix, SizeMix):
         or
             Frame.text_frame()
 
-
         Args:
-
-            name -- str
-
-            draw_id -- str
-
-            style -- str
-
-            position -- (str, str)
-
-            size -- (str, str)
-
-            z_index -- int (default 0)
-
-            presentation_class -- str
-
-            anchor_type -- 'page', 'frame', 'paragraph', 'char' or 'as-char'
-
-            anchor_page -- int, page number is anchor_type is 'page'
-
-            layer -- str
-
-            presentation_style -- str
+            name: The name of the frame.
+            draw_id: The ID of the drawing object.
+            style: The name of the style to apply to the frame.
+            position: The position of the frame as a (x, y) tuple of strings
+                including units (e.g., ('1cm', '1cm')).
+            size: The size of the frame as a (width, height) tuple of strings
+                including units (e.g., ('1cm', '1cm')). Defaults to ('1cm', '1cm').
+            z_index: The z-index for stacking order. Defaults to 0.
+            presentation_class: The presentation class of the frame.
+            anchor_type: How the frame is anchored to the document. Can be
+                'page', 'frame', 'paragraph', 'char', or 'as-char'.
+            anchor_page: The page number if `anchor_type` is 'page'.
+            layer: The drawing layer to which the frame belongs.
+            presentation_style: The presentation style of the frame.
         """
         super().__init__(**kwargs)
         if self._do_init:
@@ -285,21 +302,32 @@ class Frame(MDDrawFrame, Element, AnchorMix, PosMix, ZMix, SizeMix):
         layer: str | None = None,
         presentation_style: str | None = None,
         **kwargs: Any,
-    ) -> Element:
+    ) -> Frame:
         """Create a ready-to-use image, since image must be embedded in a
         frame.
 
         The optional text will appear above the image.
 
         Args:
+            image: A `DrawImage` element or the URL of the image.
+            text: Optional text to appear above the image.
+            name: The name of the frame.
+            draw_id: The ID of the drawing object.
+            style: The name of the style to apply to the frame.
+            position: The position of the frame as a (x, y) tuple of strings
+                including units (e.g., ('1cm', '1cm')).
+            size: The size of the frame as a (width, height) tuple of strings
+                including units (e.g., ('1cm', '1cm')). Defaults to ('1cm', '1cm').
+            z_index: The z-index for stacking order. Defaults to 0.
+            presentation_class: The presentation class of the frame.
+            anchor_type: How the frame is anchored to the document. Can be
+                'page', 'frame', 'paragraph', 'char', or 'as-char'.
+            anchor_page: The page number if `anchor_type` is 'page'.
+            layer: The drawing layer to which the frame belongs.
+            presentation_style: The presentation style of the frame.
 
-            image -- DrawImage or str, DrawImage element or URL of the image
-
-            text -- str, text for the image
-
-            See Frame() initialization for the other arguments
-
-        Returns: Frame
+        Returns:
+            Frame: The created Frame element.
         """
         frame = cls(
             name=name,
@@ -337,22 +365,33 @@ class Frame(MDDrawFrame, Element, AnchorMix, PosMix, ZMix, SizeMix):
         layer: str | None = None,
         presentation_style: str | None = None,
         **kwargs: Any,
-    ) -> Element:
+    ) -> Frame:
         """Create a ready-to-use text box, since text box must be embedded in a
         frame.
 
         The optional text will appear above the image.
 
         Args:
+            text_or_element: The text content of the text box, can be a string,
+                an `Element`, or an iterable of strings/Elements.
+            text_style: The name of the style for the text within the text box.
+            name: The name of the frame.
+            draw_id: The ID of the drawing object.
+            style: The name of the style to apply to the frame.
+            position: The position of the frame as a (x, y) tuple of strings
+                including units (e.g., ('1cm', '1cm')).
+            size: The size of the frame as a (width, height) tuple of strings
+                including units (e.g., ('1cm', '1cm')). Defaults to ('1cm', '1cm').
+            z_index: The z-index for stacking order. Defaults to 0.
+            presentation_class: The presentation class of the frame.
+            anchor_type: How the frame is anchored to the document. Can be
+                'page', 'frame', 'paragraph', 'char', or 'as-char'.
+            anchor_page: The page number if `anchor_type` is 'page'.
+            layer: The drawing layer to which the frame belongs.
+            presentation_style: The presentation style of the frame.
 
-            text_or_element -- str or Element, or list of them, text content
-                               of the text box.
-
-            text_style -- str, name of the style for the text
-
-            See Frame() initialization for the other arguments
-
-        Returns: Frame
+        Returns:
+            Frame: The created Frame element.
         """
         frame = cls(
             name=name,
@@ -373,6 +412,7 @@ class Frame(MDDrawFrame, Element, AnchorMix, PosMix, ZMix, SizeMix):
 
     @property
     def text_content(self) -> str:
+        'Get or set the "draw:text-box" text content.'
         text_box = self.get_element("draw:text-box")
         if text_box is None:
             return ""
@@ -397,37 +437,48 @@ class Frame(MDDrawFrame, Element, AnchorMix, PosMix, ZMix, SizeMix):
         url: str | None = None,
         content: str | None = None,
     ) -> DrawImage | None:
-        return self.get_element("draw:image")  # type: ignore[return-value]
+        return cast(Union[None, DrawImage], self.get_element("draw:image"))
 
-    def set_image(self, url_or_element: DrawImage | str) -> Element:
+    def set_image(self, url_or_element: DrawImage | str) -> DrawImage:
         image: DrawImage | None = self.get_image()
         if image is None:
-            if isinstance(url_or_element, Element):
-                image = url_or_element
-                self.append(image)
+            if isinstance(url_or_element, str):
+                draw_image = DrawImage(url_or_element)
+                self.append(draw_image)
             else:
-                image = DrawImage(url_or_element)
-                self.append(image)
+                draw_image = url_or_element
+                self.append(draw_image)
         else:
-            if isinstance(url_or_element, Element):
-                image.delete()
-                image = url_or_element
-                self.append(image)
+            if isinstance(url_or_element, str):
+                draw_image = image
+                draw_image.url = url_or_element
             else:
-                image.set_url(url_or_element)  # type: ignore
-        return image
+                image.delete()
+                draw_image = url_or_element
+                self.append(draw_image)
+        return draw_image
 
-    def get_text_box(self) -> Element | None:
-        return self.get_element("draw:text-box")
+    def get_text_box(self) -> DrawTextBox | None:
+        return cast(Union[None, DrawTextBox], self.get_element("draw:text-box"))
 
     def set_text_box(
         self,
         text_or_element: Iterable[Element | str] | Element | str,
         text_style: str | None = None,
-    ) -> Element:
-        text_box = self.get_text_box()
+    ) -> DrawTextBox:
+        """Set the text box content of the frame.
+
+        Args:
+            text_or_element: The text content of the text box, can be a string,
+                an `Element`, or an iterable of strings/Elements.
+            text_style: The name of the style for the text within the text box.
+
+        Returns:
+            DrawTextBox: The text box element.
+        """
+        text_box: DrawTextBox | None = self.get_text_box()
         if text_box is None:
-            text_box = Element.from_tag("draw:text-box")
+            text_box = DrawTextBox()
             self.append(text_box)
         else:
             text_box.clear()
@@ -461,24 +512,28 @@ class Frame(MDDrawFrame, Element, AnchorMix, PosMix, ZMix, SizeMix):
         for element in self.children:
             tag = element.tag
             if tag == "draw:image":
-                if context["rst_mode"]:
+                if context.get("rst_mode"):
                     filename = element.get_attribute("xlink:href")
-
                     # Compute width and height
                     width, height = self.size
                     if width is not None:
-                        width = Unit(width)
-                        width = width.convert("px", DPI)
+                        uwidth = Unit(width)
+                        uwidth = uwidth.convert("px", DPI)
+                        width = str(uwidth)
                     if height is not None:
-                        height = Unit(height)
-                        height = height.convert("px", DPI)
-
+                        uheight = Unit(height)
+                        uheight = uheight.convert("px", DPI)
+                        height = str(uheight)
                     # Insert or not ?
-                    if context["no_img_level"]:
-                        context["img_counter"] += 1
-                        ref = f"|img{context['img_counter']}|"
+                    if context.get("no_img_level"):
+                        counter = context.get("img_counter") or 0
+                        counter += 1
+                        context["img_counter"] = counter
+                        ref = f"|img{counter}|"
                         result.append(ref)
-                        context["images"].append((ref, filename, (width, height)))
+                        images = context.get("images") or []
+                        images.append((ref, filename, width, height))
+                        context["images"] = images
                     else:
                         result.append(f"\n.. image:: {filename}\n")
                         if width is not None:
@@ -498,10 +553,10 @@ class Frame(MDDrawFrame, Element, AnchorMix, PosMix, ZMix, SizeMix):
 Frame._define_attribut_property()
 
 
-class DrawTextBox(MDDrawTextBox, SectionMixin):
+class DrawTextBox(MDDrawTextBox, ListMixin, TocMixin, SectionMixin):
     """ODF text box, "draw:text-box".
 
-    Minimal class to facilitate internal iteration.
+    Minimal class to facilitate internal iterations.
     """
 
     _tag = "draw:text-box"
