@@ -1,4 +1,4 @@
-# Copyright 2018-2025 Jérôme Dumonteil
+# Copyright 2018-2026 Jérôme Dumonteil
 # Copyright (c) 2009-2013 Ars Aperta, Itaapy, Pierlis, Talend.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -42,6 +42,7 @@ from .note import NoteMixin
 from .spacer import Spacer
 from .span import Span
 from .tab import Tab
+from .user_field import UserDefinedMixin
 
 __all__ = [
     "LineBreak",
@@ -54,7 +55,13 @@ __all__ = [
 
 
 class Paragraph(
-    MDParagraph, LinkMixin, ParaFormattedTextMixin, ParaMixin, NoteMixin, Element
+    MDParagraph,
+    UserDefinedMixin,
+    LinkMixin,
+    ParaFormattedTextMixin,
+    ParaMixin,
+    NoteMixin,
+    Element,
 ):
     """An ODF paragraph, "text:p".
 
@@ -77,10 +84,10 @@ class Paragraph(
         """Initialize a Paragraph element (`text:p`).
 
         Args:
-            text_or_element (str | bytes | Element | None): Initial content for the paragraph.
+            text_or_element: Initial content for the paragraph.
                 If a string/bytes, it's treated as plain text. If an `Element`, it's appended.
-            style (str | None): The name of the style to apply to the paragraph.
-            formatted (bool): If True (default), special characters (`\\n`, `\\t`, multiple spaces)
+            style: The name of the style to apply to the paragraph.
+            formatted: If True (default), special characters (`\\n`, `\\t`, multiple spaces)
                 in `text_or_element` are converted to their ODF tag equivalents.
                 If False, only extra whitespace is removed.
             **kwargs: Additional keyword arguments for the parent `Element` class.
