@@ -1,4 +1,4 @@
-# Copyright 2018-2025 Jérôme Dumonteil
+# Copyright 2018-2026 Jérôme Dumonteil
 # Copyright (c) 2009-2010 Ars Aperta, Itaapy, Pierlis, Talend.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -27,9 +27,17 @@ from .element import register_element_class
 from .mixin_link import LinkMixin
 from .note import NoteMixin
 from .reference import ReferenceMixin
+from .user_field import UserDefinedMixin
 
 
-class RubyBase(LinkMixin, ReferenceMixin, BookmarkMixin, AnnotationMixin, NoteMixin):
+class RubyBase(
+    UserDefinedMixin,
+    LinkMixin,
+    ReferenceMixin,
+    BookmarkMixin,
+    AnnotationMixin,
+    NoteMixin,
+):
     """Represents the base text for a ruby annotation, "text:ruby-base".
 
     This element contains the text content that is to be annotated. It can
