@@ -1,4 +1,4 @@
-# Copyright 2018-2025 Jérôme Dumonteil
+# Copyright 2018-2026 Jérôme Dumonteil
 # Copyright (c) 2009-2010 Ars Aperta, Itaapy, Pierlis, Talend.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -27,6 +27,8 @@ from typing import Any, Union, cast
 
 from .element import Element, PropDef, register_element_class
 from .mixin_link import LinkMixin
+from .mixin_list import ListMixin
+from .mixin_toc import TocMixin
 
 
 class SectionMixin(Element):
@@ -59,8 +61,8 @@ class SectionMixin(Element):
         """Return all sections that match the criteria.
 
         Args:
-            style (str, optional): The style name to filter by.
-            content (str, optional): A regex to match in the section content.
+            style: The style name to filter by.
+            content: A regex to match in the section content.
 
         Returns:
             list[Section]: A list of matching Section elements.
@@ -89,9 +91,9 @@ class SectionMixin(Element):
         """Return the section that matches the criteria.
 
         Args:
-            position (int, optional): The index of the section to return.
+            position: The index of the section to return.
                 Defaults to 0 (first section).
-            content (str, optional): A regex to match in the section content.
+            content: A regex to match in the section content.
 
         Returns:
             Section or None: The matching Section element, or None if not found.
@@ -104,7 +106,7 @@ class SectionMixin(Element):
         )
 
 
-class Section(LinkMixin, SectionMixin):
+class Section(ListMixin, TocMixin, LinkMixin, SectionMixin):
     """Represents a section within a text document, "text:section".
 
     A section is a container for document content, often used for
@@ -126,8 +128,8 @@ class Section(LinkMixin, SectionMixin):
         """Create a Section element.
 
         Args:
-            style (str, optional): The style name for the section.
-            name (str, optional): The name of the section.
+            style: The style name for the section.
+            name: The name of the section.
         """
         super().__init__(**kwargs)
         if self._do_init:
@@ -140,7 +142,7 @@ class Section(LinkMixin, SectionMixin):
         """Return the formatted text content of the section.
 
         Args:
-            context (dict, optional): A dictionary of context variables.
+            context: A dictionary of context variables.
 
         Returns:
             str: The formatted text content.
