@@ -1,4 +1,4 @@
-# Copyright 2018-2025 Jérôme Dumonteil
+# Copyright 2018-2026 Jérôme Dumonteil
 # Copyright (c) 2009-2013 Ars Aperta, Itaapy, Pierlis, Talend.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -37,11 +37,13 @@ from .mixin_md import MDParagraph, MDSpan
 from .mixin_paragraph import ParaMixin
 from .mixin_paragraph_formatted import ParaFormattedTextMixin
 from .note import NoteMixin
+from .user_field import UserDefinedMixin
 
 
 class Span(
     MDSpan,
     MDParagraph,
+    UserDefinedMixin,
     LinkMixin,
     ParaFormattedTextMixin,
     ParaMixin,
@@ -77,9 +79,9 @@ class Span(
         <TAB> and multiple spaces replaced by ODF corresponding tags.
 
         Args:
-            text (str, optional): The text content for the span.
-            style (str, optional): The style name for the span.
-            formatted (bool): If True, special characters in `text` are
+            text: The text content for the span.
+            style: The style name for the span.
+            formatted: If True, special characters in `text` are
                 replaced by ODF corresponding tags. Defaults to True.
         """
         super().__init__(**kwargs)
