@@ -1,4 +1,4 @@
-# Copyright 2018-2025 Jérôme Dumonteil
+# Copyright 2018-2026 Jérôme Dumonteil
 # Copyright (c) 2009-2013 Ars Aperta, Itaapy, Pierlis, Talend.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -21,80 +21,106 @@
 #          Jerome Dumonteil <jerome.dumonteil@itaapy.com>
 """Classes related to user-defined fields in ODF documents.
 
-This module provides classes for managing user field declarations and their
-instances within the document content, such as 'text:user-field-decls',
-'text:user-field-decl', 'text:user-field-get', and 'text:user-defined'.
+This module provides classes for managing user field declarations
+content within the document, "text:user-defined", text:user-field-get",
+"text:user-field-input".
 """
 
 from __future__ import annotations
 
-from typing import Any
+from typing import TYPE_CHECKING, Any, Union, cast
 
-from .document import Document
 from .element import Element, PropDef, register_element_class
 from .element_typed import ElementTyped
 
+# for compatibility for version <= 3.18.2
+from .user_field_declaration import (  # noqa: F401
+    UserFieldDecl,
+    UserFieldDecls,
+)
 
-class UserFieldDecls(Element):
-    """A container for user field declarations, "text:user-field-decls".
+if TYPE_CHECKING:
+    from datetime import datetime, timedelta
+    from decimal import Decimal
 
-    This element groups all the 'text:user-field-decl' elements in the
-    document's meta information.
+    from .document import Document
+
+
+class UserDefinedMixin(Element):
+    """Mixin class for classes containing user defined fields.
+
+    Used by the following classes:
+        - "text:a"
+        - "text:h"
+        - "text:meta"
+        - "text:meta-field"
+        - "text:p"
+        - "text:ruby-base"
+        - "text:span"
+
+    and "office:text", "office:spreadsheet","office:presentation" for
+    compatibility with previous versions.
     """
 
-    _tag = "text:user-field-decls"
+    def get_user_defined_list(self) -> list[UserDefined]:
+        """Returns all user-defined field declarations as a list.
 
+        Returns:
+            list[UserDefined]: A list of all UserDefined instances that are descendants of this element.
+        """
+        return cast(
+            list[UserDefined],
+            self._filtered_elements(
+                "descendant::text:user-defined",
+            ),
+        )
 
-class UserFieldDecl(ElementTyped):
-    """A declaration of a user field, "text:user-field-decl".
+    @property
+    def user_defined_list(self) -> list[UserDefined]:
+        """Returns all user-defined field declarations as a list.
 
-    This element, typically found within 'text:user-field-decls', defines a
-    user-defined field, its name, type, and current value.
+        Returns:
+            list[UserDefined]: A list of all UserDefined instances that are descendants of this element.
+        """
+        return self.get_user_defined_list()
 
-    Attributes:
-        name (str): The unique name of the user field.
-    """
-
-    _tag = "text:user-field-decl"
-    _properties = (PropDef("name", "text:name"),)
-
-    def __init__(
-        self,
-        name: str | None = None,
-        value: Any = None,
-        value_type: str | None = None,
-        **kwargs: Any,
-    ) -> None:
-        """Initializes the UserFieldDecl element.
+    def get_user_defined(self, name: str, position: int = 0) -> UserDefined | None:
+        """Returns a single user-defined field declaration that matches the specified criteria.
 
         Args:
-            name (str, optional): The name of the user field.
-            value (Any, optional): The initial value of the field.
-            value_type (str, optional): The ODF value type (e.g., 'string',
-                'float'). If not provided, it is inferred from the `value`.
+            name: The name of the user-defined field to retrieve.
+            position: The 0-based index of the matching user-defined field to return.
+
+        Returns:
+            UserDefined | None: A UserDefined instance, or None if no declaration matches the criteria.
         """
-        super().__init__(**kwargs)
-        if self._do_init:
-            if name:
-                self.name = name
-            self.set_value_and_type(value=value, value_type=value_type)
+        return cast(
+            Union[None, UserDefined],
+            self._filtered_element(
+                "descendant::text:user-defined", position, text_name=name
+            ),
+        )
 
-    def set_value(self, value: Any) -> None:
-        """Sets the value of the user field declaration.
-
-        This method updates the value and value type of the declaration,
-        preserving its name.
+    def get_user_defined_value(
+        self, name: str, value_type: str | None = None
+    ) -> bool | str | int | float | Decimal | datetime | timedelta | None:
+        """Returns the value of the specified user-defined field.
 
         Args:
-            value (Any): The new value for the field.
+            name: The name of the user-defined field to retrieve its value.
+            value_type: The expected type of the user-defined field's value.
+                Can be 'boolean', 'date', 'float', 'string', 'time', or None
+                for automatic type detection.
+
+        Returns:
+            bool | str | int | float | Decimal | datetime | timedelta | None:
+                The value of the user-defined field, cast to the most appropriate
+                Python type, or None if the user-defined field is not found.
         """
-        name = self.get_attribute("text:name")
-        self.clear()
-        self.set_value_and_type(value=value)
-        self.set_attribute("text:name", name)
-
-
-UserFieldDecl._define_attribut_property()
+        user_defined = self.get_user_defined(name)
+        if user_defined is None:
+            return None
+        return user_defined.get_value(value_type)  # type: ignore[return-value]
 
 
 class UserFieldGet(ElementTyped):
@@ -127,12 +153,12 @@ class UserFieldGet(ElementTyped):
         """Initializes the UserFieldGet element.
 
         Args:
-            name (str, optional): The name of the user field to get.
-            value (Any, optional): An initial value to display.
-            value_type (str, optional): The ODF value type.
-            text (str, optional): The textual representation to display. If
+            name: The name of the user field to get.
+            value: An initial value to display.
+            value_type: The ODF value type.
+            text: The textual representation to display. If
                 not provided, it's generated from `value`.
-            style (str, optional): The data style name for formatting.
+            style: The data style name for formatting.
         """
         super().__init__(**kwargs)
         if self._do_init:
@@ -199,12 +225,12 @@ class UserDefined(ElementTyped):
         name from that document.
 
         Args:
-            name (str): The name of the user-defined field.
-            value (Any, optional): The value of the field.
-            value_type (str, optional): The ODF value type (e.g., 'string').
-            text (str, optional): The textual representation of the value.
-            style (str, optional): The data style name for formatting.
-            from_document (Document, optional): A document from which to load
+            name: The name of the user-defined field.
+            value: The value of the field.
+            value_type: The ODF value type (e.g., 'string').
+            text: The textual representation of the value.
+            style: The data style name for formatting.
+            from_document: A document from which to load
                 the field's value from the meta section.
         """
         super().__init__(**kwargs)
@@ -228,8 +254,6 @@ class UserDefined(ElementTyped):
 
 UserDefined._define_attribut_property()
 
-register_element_class(UserFieldDecls)
-register_element_class(UserFieldDecl)
 register_element_class(UserFieldGet)
 register_element_class(UserFieldInput)
 register_element_class(UserDefined)
