@@ -1,4 +1,4 @@
-# Copyright 2018-2025 Jérôme Dumonteil
+# Copyright 2018-2026 Jérôme Dumonteil
 # Copyright (c) 2009-2010 Ars Aperta, Itaapy, Pierlis, Talend.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -82,5 +82,10 @@ SUBCLASS_STYLES = {"background-image"}
 FAMILY_MAPPING = {**_BASE_FAMILY_MAP, **_FALSE_FAMILY_MAP}
 
 FALSE_FAMILY_MAP_REVERSE = {v: k for k, v in _FALSE_FAMILY_MAP.items()}
-SUBCLASSED_STYLES = {"style:background-image", "style:master-page", "style:page-layout"}
+SUBCLASSED_STYLES = {
+    "style:background-image",
+    "style:master-page",
+    "style:page-layout",
+    "draw:marker",
+}
 STYLES_TO_REGISTER = (set(FAMILY_MAPPING.values()) | OTHER_STYLES) - SUBCLASSED_STYLES
