@@ -1,4 +1,4 @@
-# Copyright 2018-2025 Jérôme Dumonteil
+# Copyright 2018-2026 Jérôme Dumonteil
 # Copyright (c) 2009-2010 Ars Aperta, Itaapy, Pierlis, Talend.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -38,6 +38,7 @@ from .element import Element, EText
 
 if TYPE_CHECKING:
     from .body import Body
+    from .settings import OfficeSettings
 
 
 class XmlPart:
@@ -56,8 +57,8 @@ class XmlPart:
         """Initializes an XmlPart instance.
 
         Args:
-            part_name (str): The name of the XML part (e.g., "content.xml").
-            container (Container): The ODF container (zip file) that holds
+            part_name: The name of the XML part (e.g., "content.xml").
+            container: The ODF container (zip file) that holds
                 this XML part.
         """
         self.part_name = part_name
@@ -113,7 +114,7 @@ class XmlPart:
         return body
 
     @property
-    def body(self) -> Body:
+    def body(self) -> Body | OfficeSettings:
         """The document body element ('office:body').
 
         This property provides access to the main content body of the XML part.
@@ -125,7 +126,7 @@ class XmlPart:
         """Sets the document body with a new Element.
 
         Args:
-            new_body (Element): The new 'office:body' element to set.
+            new_body: The new 'office:body' element to set.
         """
         body = self._get_body()
         tail = body.tail
@@ -141,7 +142,7 @@ class XmlPart:
         The XPath query is applied to the root of this XML part.
 
         Args:
-            xpath_query (str): The XPath query string.
+            xpath_query: The XPath query string.
 
         Returns:
             list[Element]: A list of matching Element objects.
@@ -154,7 +155,7 @@ class XmlPart:
         The XPath query is applied to the root of this XML part.
 
         Args:
-            xpath_query (str): The XPath query string.
+            xpath_query: The XPath query string.
 
         Returns:
             Element | None: The first matching Element object, or None if
@@ -166,7 +167,7 @@ class XmlPart:
         """Deletes a specified child element from the XML tree.
 
         Args:
-            child (Element): The child element to delete.
+            child: The child element to delete.
         """
         child.delete()
 
@@ -174,7 +175,7 @@ class XmlPart:
         """Applies an XPath query to the root of the XML part and its subtree.
 
         Args:
-            xpath_query (str): The XPath query string.
+            xpath_query: The XPath query string.
 
         Returns:
             list[Element | EText]: A list of Element or EText instances
@@ -207,7 +208,7 @@ class XmlPart:
         """Serializes the XML part to bytes.
 
         Args:
-            pretty (bool): If True, the output XML will be pretty-printed.
+            pretty: If True, the output XML will be pretty-printed.
                 Defaults to False.
 
         Returns:
