@@ -1,4 +1,4 @@
-# Copyright 2018-2025 Jérôme Dumonteil
+# Copyright 2018-2026 Jérôme Dumonteil
 # Copyright (c) 2009-2010 Ars Aperta, Itaapy, Pierlis, Talend.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -40,7 +40,6 @@ from odfdo.element import (
     register_element_class,
     xpath_compile,
 )
-from odfdo.list import List
 from odfdo.named_range import NamedRange
 from odfdo.paragraph import Paragraph
 from odfdo.section import Section
@@ -883,32 +882,6 @@ def test_get_inner_text_no_content():
     assert result is None
 
 
-def test_svg_title_1():
-    element = Element.from_tag("<text:p>x</text:p>")
-    result = element.svg_title
-    assert result is None
-
-
-def test_svg_title_2():
-    element = Element.from_tag("<text:p>x</text:p>")
-    element.svg_title = "content"
-    result = element.svg_title
-    assert result == "content"
-
-
-def test_svg_description_1():
-    element = Element.from_tag("<text:p>x</text:p>")
-    result = element.svg_description
-    assert result is None
-
-
-def test_svg_description_2():
-    element = Element.from_tag("<text:p>x</text:p>")
-    element.svg_description = "content"
-    result = element.svg_description
-    assert result == "content"
-
-
 def test_sections(sample):
     content = sample.content
     result = content.body.sections
@@ -934,51 +907,6 @@ def test_append_named_range_in_class(tag):
     assert isinstance(result, NamedRange)
 
 
-def test_get_lists_1():
-    element = Element.from_tag("office:text")
-    result = element.get_lists()
-    assert result == []
-
-
-def test_get_lists_2():
-    element = Element.from_tag("office:text")
-    result = element.lists
-    assert result == []
-
-
-def test_get_lists_3():
-    element = Element.from_tag("office:text")
-    element.insert(List(["a", "b"]), position=0)
-    result = element.lists
-    assert len(result) == 1
-    assert isinstance(result[0], List)
-
-
-def test_get_lists_4():
-    element = Element.from_tag("office:text")
-    element.insert(List(["a", "b"]), position=0)
-    element.insert(List(["c"]), position=0)
-    result = element.lists
-    assert len(result) == 2
-    assert isinstance(result[0], List)
-
-
-def test_get_list_1():
-    element = Element.from_tag("office:text")
-    element.insert(List(["a", "b"]), position=0)
-    element.insert(List(["c"]), position=0)
-    result = element.get_list(content="c")
-    assert isinstance(result, List)
-
-
-def test_get_list_2():
-    element = Element.from_tag("office:text")
-    element.insert(List(["a", "b"]), position=0)
-    element.insert(List(["c"]), position=0)
-    result = element.get_list(content="z")
-    assert result is None
-
-
 def test_element_get_attribute_int_default_1():
     element = Element.from_tag("<form:form/>")
     result = element._get_attribute_int_default("form:tab-index", 0)
